import { Plugin } from 'ckeditor5/src/core';
import InsertNeonHeadingCommand from './insertneonheadingcommand';

export default class NeonHeadingEditing extends Plugin {
    static get pluginName() {
        return 'NeonHeadingEditing';
    }

    init() {
        const editor = this.editor;

        this._defineSchema();
        this._defineConverters();

        const command = new InsertNeonHeadingCommand(editor);
        editor.commands.add('insertNeonHeading', command);
        const registeredCommand = editor.commands.get('insertNeonHeading');
    }

    _defineSchema() {
        const schema = this.editor.model.schema;

        [1, 2, 3, 4, 5, 6].forEach(level => {
            const headingName = 'heading' + level;
            if (schema.isRegistered(headingName)) {
                schema.extend(headingName, {
                    allowAttributes: ['class']
                });
            }
        });
    }

    _defineConverters() {
        const conversion = this.editor.conversion;

        conversion.for('downcast').attributeToAttribute({
            model: 'class',
            view: 'class'
        });

        conversion.for('upcast').attributeToAttribute({
            model: 'class',
            view: 'class'
        });

        conversion.for('editingDowncast').attributeToAttribute({
            model: 'class',
            view: 'class'
        });
    }
}
