import { Plugin } from 'ckeditor5/src/core';
import { ButtonView } from 'ckeditor5/src/ui';
import icon from '../../../../icons/neonheading.svg';

export default class NeonHeadingUI extends Plugin {
  static get pluginName() {
    return 'NeonHeadingUI';
  }

  init() {
    const editor = this.editor;
    if (typeof window.Drupal === 'undefined' || typeof window.jQuery === 'undefined') {
      return;
    }
    const Drupal = window.Drupal;
    const jQuery = window.jQuery;

    editor.ui.componentFactory.add('neonHeading', locale => {
      const button = new ButtonView(locale);
      const command = editor.commands.get('insertNeonHeading');

      button.set({
        label: editor.t('Neon Heading'),
        icon,
        tooltip: true
      });

      button.bind('isEnabled').to(command);

      button.on('execute', () => {
        try {
          const $content = jQuery(`
            <div class="neon-heading-form">
              <div class="form-row">
                <div class="form-group">
                  <label for="heading-level">Heading Level:</label>
                  <select id="heading-level">
                    <option value="2">H2</option>
                    <option value="3">H3</option>
                    <option value="4">H4</option>
                    <option value="5">H5</option>
                    <option value="6">H6</option>
                  </select>
                </div>
                <div class="form-group">
                  <label for="neon-class">Neon Color:</label>
                  <select id="neon-class">
                    <option value="neon-title neon-blue">Blue Neon</option>
                    <option value="neon-title neon-red">Red Neon</option>
                    <option value="neon-title neon-green">Green Neon</option>
                    <option value="neon-title neon-purple">Purple Neon</option>
                    <option value="neon-title neon-pink">Pink Neon</option>
                    <option value="neon-title neon-orange">Orange Neon</option>
                    <option value="neon-title neon-yellow">Yellow Neon</option>
                    <option value="neon-title neon-cyan">Cyan Neon</option>
                    <option value="neon-title neon-magenta">Magenta Neon</option>
                    <option value="neon-title neon-lime">Lime Neon</option>
                  </select>
                </div>
              </div>
            </div>
          `);

          const dialog = Drupal.dialog($content, {
            title: Drupal.t('Insert Neon Heading'),
            buttons: [
              {
                text: Drupal.t('Insert'),
                class: 'button button--primary',
                click: function() {
                  const level = jQuery('#heading-level').val();
                  const className = jQuery('#neon-class').val();
                  if (!level || !className) {
                    return;
                  }
                  editor.execute('insertNeonHeading', {
                    level: parseInt(level),
                    value: className
                  });
                  dialog.close();
                  editor.editing.view.focus();
                  editor.editing.view.scrollToTheSelection();
                }
              },
              {
                text: Drupal.t('Cancel'),
                class: 'button',
                click: function() {
                  dialog.close();
                }
              }
            ],
            dialogClass: 'neon-heading-dialog',
            width: '500px',
            height: 'auto',
            closeOnEscape: true,
            modal: true
          });

          dialog.showModal();
        } catch (error) {
          Drupal.notifyError(Drupal.t('An error occurred while creating the heading'));
        }
      });

      return button;
    });
  }
}
